<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>PenToolBar</name>
    <message>
        <location filename="../PenToolBar.js" line="+26"/>
        <source>Pen</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Otwieranie ostatniego pliku...
Otwieranie ostatniego pliku
Otwieranie przerwane</translatorcomment>
        <translation>Pióro</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Reset to Defaults</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Przywróć domyślne</translation>
    </message>
</context>
</TS>
